import { CommonModule } from '@angular/common';
import { NgModule, OpaqueToken } from '@angular/core';
import { NotifierContainerComponent } from './components/notifier-container.component';
import { NotifierNotificationComponent } from './components/notifier-notification.component';
import { NotifierConfig } from './models/notifier-config.model';
import { NotifierAnimationService } from './services/notifier-animation.service';
import { NotifierQueueService } from './services/notifier-queue.service';
import { NotifierService } from './services/notifier.service';
// tslint:disable variable-name
/**
 * Dependency Injection token for custom notifier options
 */
export var CustomNotifierOptions = new OpaqueToken('NotifierOptions');
// tslint:enable variable-name
/**
 * Factory for creating a notifier configuration object
 *
 * Sidenote:
 * This functionality had to be extracted from the NotifierModule.forRoot function, described below. Otherwhise, the Angular AoT compiler
 * would throw errors. For further details, also see:
 * - Angular issue #11262 <https://github.com/angular/angular/issues/11262>
 * - Angular issue #10789 <https://github.com/angular/angular/issues/10789>
 */
export function notifierConfigFactory(options) {
    return new NotifierConfig(options);
}
/**
 * Notifier module
 */
export var NotifierModule = (function () {
    function NotifierModule() {
    }
    /**
     * Setup custom module (service) configuration
     */
    NotifierModule.forRoot = function (options) {
        return {
            ngModule: NotifierModule,
            providers: [
                {
                    provide: CustomNotifierOptions,
                    useValue: options
                },
                {
                    deps: [
                        CustomNotifierOptions
                    ],
                    provide: NotifierConfig,
                    useFactory: notifierConfigFactory
                }
            ]
        };
    };
    NotifierModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        NotifierContainerComponent,
                        NotifierNotificationComponent
                    ],
                    exports: [
                        NotifierContainerComponent
                    ],
                    imports: [
                        CommonModule
                    ],
                    providers: [
                        NotifierAnimationService,
                        NotifierService,
                        NotifierQueueService
                    ]
                },] },
    ];
    /** @nocollapse */
    NotifierModule.ctorParameters = function () { return []; };
    return NotifierModule;
}());
//# sourceMappingURL=notifier.module.js.map